@@ -19,6 +19,7 @@
     *************************************************************************
 */
 #include "jabbercapabilitiesmanager.h"
+#include "jabber_protocol_debug.h"
 
 #include <qstring.h>
 #include <qstringlist.h>
@@ -28,7 +29,6 @@
 #include <qtextstream.h>
 
 #include <kstandarddirs.h>
-#include <kdebug.h>
 
 #include <xmpp_tasks.h>
 
@@ -171,7 +171,7 @@ void JabberCapabilitiesManager::CapabilitiesInformation::addJid(const Jid& jid,
 
 void JabberCapabilitiesManager::CapabilitiesInformation::removeJid(const Jid& jid)
 {
-	kDebug(JABBER_DEBUG_GLOBAL) << "Unregistering " << QString(jid.full()).replace('%',"%%");
+	qCDebug(JABBER_PROTOCOL_LOG) << "Unregistering " << QString(jid.full()).replace('%',"%%");
 
 	JidList::Iterator it = m_jids.begin();
 	while( it != m_jids.end() ) 
@@ -189,7 +189,7 @@ void JabberCapabilitiesManager::CapabilitiesInformation::removeJid(const Jid& ji
 
 QPair<Jid,JabberAccount*> JabberCapabilitiesManager::CapabilitiesInformation::nextJid(const Jid& jid, const Task* t)
 {
-	kDebug(JABBER_DEBUG_GLOBAL) << "Looking for next JID";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Looking for next JID";
 
 	JidList::ConstIterator it = m_jids.constBegin(), itEnd = m_jids.constEnd();
 	for( ; it != itEnd; ++it) 
@@ -199,14 +199,14 @@ QPair<Jid,JabberAccount*> JabberCapabilitiesManager::CapabilitiesInformation::ne
 			it++;
 			if (it == itEnd) 
 			{
-				kDebug(JABBER_DEBUG_GLOBAL) << "No more JIDs";
+				qCDebug(JABBER_PROTOCOL_LOG) << "No more JIDs";
 
 				return QPair<Jid,JabberAccount*>(Jid(),0L);
 			}
 			else if( (*it).second->isConnected() ) 
 			{
 				//qDebug("caps.cpp: Account isn't active");
-				kDebug(JABBER_DEBUG_GLOBAL) << "Account isn't connected.";
+				qCDebug(JABBER_PROTOCOL_LOG) << "Account isn't connected.";
 
 				return QPair<Jid,JabberAccount*>( (*it).first,(*it).second );
 			}
@@ -270,7 +270,7 @@ void JabberCapabilitiesManager::CapabilitiesInformation::fromXml(const QDomEleme
 {
 	if( element.tagName() != "info") 
 	{
-		kDebug(JABBER_DEBUG_GLOBAL) << "Invalid info element";
+		qCDebug(JABBER_PROTOCOL_LOG) << "Invalid info element";
 		return;
 	}
 	
@@ -282,7 +282,7 @@ void JabberCapabilitiesManager::CapabilitiesInformation::fromXml(const QDomEleme
 		QDomElement infoElement = node.toElement();
 		if( infoElement.isNull() ) 
 		{
-			kDebug(JABBER_DEBUG_GLOBAL) << "Null element";
+			qCDebug(JABBER_PROTOCOL_LOG) << "Null element";
 			continue;
 		}
 
@@ -300,7 +300,7 @@ void JabberCapabilitiesManager::CapabilitiesInformation::fromXml(const QDomEleme
 		}
 		else 
 		{
-			kDebug(JABBER_DEBUG_GLOBAL) << "Unknown element";
+			qCDebug(JABBER_PROTOCOL_LOG) << "Unknown element";
 		}
 
 		m_discovered = true;
@@ -335,7 +335,7 @@ JabberCapabilitiesManager::~JabberCapabilitiesManager()
 
 void JabberCapabilitiesManager::removeAccount(JabberAccount *account)
 {
-	kDebug(JABBER_DEBUG_GLOBAL) << "Removing account " << account->accountId();
+	qCDebug(JABBER_PROTOCOL_LOG) << "Removing account " << account->accountId();
 
 	QList<CapabilitiesInformation> info = d->capabilitiesInformationMap.values();
 
@@ -394,7 +394,7 @@ void JabberCapabilitiesManager::updateCapabilities(JabberAccount *account, const
 			{
 				if( !d->capabilitiesInformationMap[*newCapsIt].discovered() && d->capabilitiesInformationMap[*newCapsIt].pendingRequests() == 0 ) 
 				{
-					kDebug(JABBER_DEBUG_GLOBAL) << QString("Sending disco request to %1, node=%2").arg(QString(jid.full()).replace('%',"%%")).arg(node + '#' + (*newCapsIt).extensions());
+					qCDebug(JABBER_PROTOCOL_LOG) << QString("Sending disco request to %1, node=%2").arg(QString(jid.full()).replace('%',"%%")).arg(node + '#' + (*newCapsIt).extensions());
 
 					d->capabilitiesInformationMap[*newCapsIt].setPendingRequests(1);
 					requestDiscoInfo(account, jid, node + '#' + (*newCapsIt).extensions());
@@ -404,7 +404,7 @@ void JabberCapabilitiesManager::updateCapabilities(JabberAccount *account, const
 		else 
 		{
 			// Remove all caps specifications
-			kDebug(JABBER_DEBUG_GLOBAL) << QString("Illegal caps info from %1: node=%2, ver=%3").arg(QString(jid.full()).replace('%',"%%")).arg(node).arg(version);
+			qCDebug(JABBER_PROTOCOL_LOG) << QString("Illegal caps info from %1: node=%2, ver=%3").arg(QString(jid.full()).replace('%',"%%")).arg(node).arg(version);
 
 			d->jidCapabilitiesMap.remove( jid.full() );
 		}
@@ -442,7 +442,7 @@ void JabberCapabilitiesManager::discoRequestFinished()
 
 	DiscoItem item = discoInfo->item();
 	Jid jid = discoInfo->jid();
-	kDebug(JABBER_DEBUG_GLOBAL) << QString("Disco response from %1, node=%2, success=%3").arg(QString(jid.full()).replace('%',"%%")).arg(discoInfo->node()).arg(discoInfo->success());
+	qCDebug(JABBER_PROTOCOL_LOG) << QString("Disco response from %1, node=%2, success=%3").arg(QString(jid.full()).replace('%',"%%")).arg(discoInfo->node()).arg(discoInfo->success());
 
 	const QString &tokens = discoInfo->node();
 	int idx = tokens.lastIndexOf('#');
@@ -472,7 +472,7 @@ void JabberCapabilitiesManager::discoRequestFinished()
 			
 			// Notify affected jids.
 			QStringList jids = d->capabilitiesInformationMap[capabilities].jids();
-			kDebug(JABBER_DEBUG_GLOBAL) << "notify affected jids";
+			qCDebug(JABBER_PROTOCOL_LOG) << "notify affected jids";
 			foreach( QString jid  , jids ) 
 			{
 				emit capabilitiesChanged(jid);
@@ -483,18 +483,18 @@ void JabberCapabilitiesManager::discoRequestFinished()
 			QPair<Jid,JabberAccount*> jidAccountPair = d->capabilitiesInformationMap[capabilities].nextJid(jid,discoInfo->parent());
 			if( jidAccountPair.second ) 
 			{
-				kDebug(JABBER_DEBUG_GLOBAL) << QString("Falling back on %1.").arg(QString(jidAccountPair.first.full()).replace('%',"%%"));
+				qCDebug(JABBER_PROTOCOL_LOG) << QString("Falling back on %1.").arg(QString(jidAccountPair.first.full()).replace('%',"%%"));
 				requestDiscoInfo( jidAccountPair.second, jidAccountPair.first, discoInfo->node() );
 			}
 			else 
 			{
-				kDebug(JABBER_DEBUG_GLOBAL) << "No valid disco request avalable.";
+				qCDebug(JABBER_PROTOCOL_LOG) << "No valid disco request avalable.";
 				d->capabilitiesInformationMap[capabilities].setPendingRequests(0);
 			}
 		}
 	}
 	else 
-		kDebug(JABBER_DEBUG_GLOBAL) << QString("Current client node '%1' does not match response '%2'").arg(jidCapabilities.node()).arg(node);
+		qCDebug(JABBER_PROTOCOL_LOG) << QString("Current client node '%1' does not match response '%2'").arg(jidCapabilities.node()).arg(node);
 
 	//for (unsigned int i = 0; i < item.features().list().count(); i++) 
 	//	printf("    Feature: %s\n",item.features().list()[i].toLatin1());
@@ -517,12 +517,12 @@ void JabberCapabilitiesManager::loadCachedInformation()
 	QFile cacheFile(capsFileName);
 	if( !cacheFile.open(QIODevice::ReadOnly) )
 	{
-		kDebug(JABBER_DEBUG_GLOBAL) << "Could not open the Capabilities cache from disk.";
+		qCDebug(JABBER_PROTOCOL_LOG) << "Could not open the Capabilities cache from disk.";
 		return;
 	}
 	if( !doc.setContent(&cacheFile) )
 	{
-		kDebug(JABBER_DEBUG_GLOBAL) << "Could not set the Capabilities cache from file.";
+		qCDebug(JABBER_PROTOCOL_LOG) << "Could not set the Capabilities cache from file.";
 		return;
 	}
 	cacheFile.close();
@@ -530,7 +530,7 @@ void JabberCapabilitiesManager::loadCachedInformation()
 	QDomElement caps = doc.documentElement();
 	if( caps.tagName() != "capabilities" ) 
 	{
-		kDebug(JABBER_DEBUG_GLOBAL) << "Invalid capabilities element.";
+		qCDebug(JABBER_PROTOCOL_LOG) << "Invalid capabilities element.";
 		return;
 	}
 	
@@ -540,7 +540,7 @@ void JabberCapabilitiesManager::loadCachedInformation()
 		QDomElement element = node.toElement();
 		if( element.isNull() ) 
 		{
-			kDebug(JABBER_DEBUG_GLOBAL) << "Found a null element.";
+			qCDebug(JABBER_PROTOCOL_LOG) << "Found a null element.";
 			continue;
 		}
 
@@ -553,7 +553,7 @@ void JabberCapabilitiesManager::loadCachedInformation()
 		}
 		else 
 		{
-			kDebug(JABBER_DEBUG_GLOBAL) << "Unknow element";
+			qCDebug(JABBER_PROTOCOL_LOG) << "Unknow element";
 		}
 	}
 }
@@ -639,7 +639,7 @@ void JabberCapabilitiesManager::saveInformation()
 	QFile capsFile(capsFileName);
 	if( !capsFile.open(QIODevice::WriteOnly) ) 
 	{
-		kDebug(JABBER_DEBUG_GLOBAL	) << "Error while opening Capabilities cache file.";
+		qCDebug(JABBER_PROTOCOL_LOG) << "Error while opening Capabilities cache file.";
 		return;
 	}
 
@@ -651,4 +651,4 @@ void JabberCapabilitiesManager::saveInformation()
 	capsFile.close();
 }
 
-#include "jabbercapabilitiesmanager.moc"
+
